@@ -223,29 +223,29 @@ extern SbkConverter **SbkPySide6_QtNetworkTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 0, // const QList<QObject* > &
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 0, // const QList<QSslCertificate > &
     SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
-    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 2, // QHash<QString,QVariant >
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 3, // QList<QDnsDomainNameRecord >
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 4, // QList<QDnsHostAddressRecord >
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 5, // QList<QDnsMailExchangeRecord >
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 6, // QList<QDnsServiceRecord >
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 7, // QList<QDnsTextRecord >
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 8, // const QList<QSslError > &
+    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 2, // QMap<QByteArray,QVariant >
+    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 3, // QList<QSslCipher >
+    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 4, // QList<QNetworkProxy >
+    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 5, // QList<QNetworkAddressEntry >
+    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 6, // QList<QHostAddress >
+    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 7, // QList<QNetworkInterface >
+    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 8, // QHash<QNetworkRequest::Attribute,QVariant >
     SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 9, // const QPair<QHostAddress,int > &
-    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 10, // QList<QHostAddress >
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 11, // const QList<QHstsPolicy > &
-    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 12, // QHash<QNetworkRequest::Attribute,QVariant >
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 13, // QList<QNetworkCookie >
-    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 14, // QList<QNetworkAddressEntry >
-    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 15, // QList<QNetworkInterface >
-    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 16, // QList<QNetworkProxy >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 17, // QList<QSslCertificateExtension >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 18, // QList<QSslCertificate >
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 19, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
-    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 20, // QMap<QByteArray,QVariant >
-    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 21, // QList<QSslCipher >
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 22, // QList<QOcspResponse >
+    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 10, // QHash<QString,QVariant >
+    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 11, // const QList<QObject* > &
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 12, // QList<QNetworkCookie >
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 13, // const QList<QHstsPolicy > &
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 14, // const QList<QSslError > &
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 15, // QList<QDnsDomainNameRecord >
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 16, // QList<QDnsHostAddressRecord >
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 17, // QList<QDnsMailExchangeRecord >
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 18, // QList<QDnsServiceRecord >
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 19, // QList<QDnsTextRecord >
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 20, // QList<QOcspResponse >
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 21, // QList<QSslCertificateExtension >
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 22, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
     SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 23, // QList<QVariant >
     SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 24, // QList<QString >
     SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 25, // QMap<QString,QVariant >
