@@ -5,8 +5,8 @@ from textwrap import dedent
 __all__ = list("Qt" + body for body in
     "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Xml;Help;OpenGL;OpenGLFunctions;OpenGLWidgets;Qml;Quick;QuickControls2;QuickWidgets;Svg;SvgWidgets;UiTools;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.0.0"
-__version_info__ = (6, 0, 0, "", "")
+__version__ = "6.0.2"
+__version_info__ = (6, 0, 2, "", "")
 
 
 def _additional_dll_directories(package_dir):
@@ -57,7 +57,7 @@ def _setupQtDirectories():
         import shiboken6
     except Exception:
         paths = ', '.join(sys.path)
-        print('PySide6/__init__.py: Unable to import shiboken6 from {}'.format(paths),
+        print(f"PySide6/__init__.py: Unable to import shiboken6 from {paths}",
               file=sys.stderr)
         raise
 
